"datetime" <- function( ) {
  format(Sys.time(), "%Y-%m-%d, %X")
}

"mytime" <- function( ) {format(Sys.time(), "%X")
}

"mydate" <- function( ) format(Sys.time(), "%Y-%m-%d")
